import { ChangeDetectorRef, ComponentFactoryResolver, EventEmitter, OnDestroy, Type } from '@angular/core';
import { ComponentHostDirective } from './directives/component-host.directive';
export declare class RhzSideMenuComponent implements OnDestroy {
    private _componentFactoryResolver;
    private _cdr;
    /**
     * Place where the component will be rendered
     */
    componentHost: ComponentHostDirective;
    /**
     * Menu side to open
     */
    set side(value: 'left' | 'right');
    /**
     * Menu title
     */
    text: string;
    /**
     * Component class to render
     */
    component: Type<any>;
    /**
     * On change visibility event emitter
     */
    onChange: EventEmitter<{
        opened: boolean;
        data?: any;
    }>;
    /**
     * Component rendered reference
     */
    private _componentRef;
    /**
     * Menu side
     */
    private _side;
    /**
     * Visibility control
     */
    private _opened;
    /**
     * Slide in animation params
     */
    slideInParams: {
        [key: string]: any;
    };
    /**
     * Inject dependencies
     * @param _componentFactoryResolver: ComponentFactoryResolver
     * @param _cdr: ChangeDetectorRef
     */
    constructor(_componentFactoryResolver: ComponentFactoryResolver, _cdr: ChangeDetectorRef);
    private get _hostClasses();
    /**
     * Destroy
     */
    ngOnDestroy(): void;
    /**
     * Render input component
     */
    private _renderComponent;
    /**
     * Destroy rendered component
     */
    private _destroyComponent;
    /**
     * Check if menu is opened
     */
    isOpen(): boolean;
    /**
     * Open menu
     */
    open(): void;
    /**
     * Close menu
     */
    close(data?: any): void;
    /**
     * Emit on change event
     * @private
     */
    private _emitOnChangeEvent;
    /**
     * Block/unblock page scroll
     * @private
     */
    private _pageScroll;
    /**
     * Detect view changes
     * @private
     */
    private _detectChanges;
}
